Introduction
============

Welcome to the documentation for `romancal <https://github.com/spacetelescope/romancal>`__.
This package contains the calibration software for the WFI instrument on the Nancy Grace Roman
Space Telescope.

The romancal package processes data by applying various corrections to produce
science-ready output products, including fully calibrated individual
exposures as well as high-level data products (e.g., mosaics and catalogs).

The tools in this package allow users to run and configure the pipeline
steps to custom process the Roman data. Additionally, the romancal package
contains the interface to the Roman datamodels, the recommended method
of reading and writing Roman data files in Python.
